package com.xxfc.rv.adapter;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.v7.widget.RecyclerView;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.bumptech.glide.Glide;
import com.bumptech.glide.request.RequestOptions;
import com.xxfc.rv.ChatHolderFactory;
import com.xxfc.rv.R;
import com.xxfc.rv.audio_x.VoiceAnimView;
import com.xxfc.rv.audio_x.VoicePlayer;
import com.xxfc.rv.db.table.ChatMessage;
import com.xxfc.rv.glide.GlideOptions;
import com.xxfc.rv.glide.TransformationUtils;
import com.xxfc.rv.util.DateUtils;
import com.xxfc.rv.view.RoundImageView;

import java.util.List;

public class ChatContentAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {

    private Context mContext;
    private List<ChatMessage> messageList;
    private String mLoginUserId;

    public ChatContentAdapter(Context context, String mLoginUserId, List<ChatMessage> list) {
        this.mContext = context;
        this.mLoginUserId = mLoginUserId;
        this.messageList = list;
    }

    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        switch (i) {
            case 10:
                return new MsgFromTextHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_from_item_text, viewGroup, false));
            case 11:
                return new MsgToTextHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_to_item_text, viewGroup, false));
            case 20:
                return new MsgToPicHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_from_item_pic, viewGroup, false));
            case 21:
                return new MsgFromPicHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_to_item_pic, viewGroup, false));
            case 30:
                return new MsgFromPicHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_from_item_pic, viewGroup, false));
            case 31:
                return new MsgToPicHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_to_item_pic, viewGroup, false));
            case 40:
                return new MsgFromVoiceHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_from_item_voice, viewGroup, false));
            case 41:
                return new MsgToVoiceHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_to_item_voice, viewGroup, false));
            case 50:
                return new MsgToTextHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_to_item_text, viewGroup, false));
            case 51:
                return new MsgToTextHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_to_item_text, viewGroup, false));
            case 60:
                return new MsgToTextHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_to_item_text, viewGroup, false));
            case 61:
                return new MsgToTextHolder(LayoutInflater.from(mContext).inflate(R.layout.chat_to_item_text, viewGroup, false));
        }
        return null;
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder viewHolder, int i) {
        ChatMessage bean = messageList.get(i);
        if (bean != null) {
            if (viewHolder instanceof MsgToTextHolder) {
                setToTextContentView(bean, (MsgToTextHolder) viewHolder);
            } else if (viewHolder instanceof MsgFromTextHolder) {
                setFromTextContentView(bean, (MsgFromTextHolder) viewHolder);
            } else if (viewHolder instanceof MsgToPicHolder) {
                setToPicContentView(bean, (MsgToPicHolder) viewHolder);
            } else if (viewHolder instanceof MsgFromPicHolder) {
                setFromPicContentView(bean, (MsgFromPicHolder) viewHolder);
            } else if (viewHolder instanceof MsgToVoiceHolder) {
                setToVoiceContentView(bean, (MsgToVoiceHolder) viewHolder);
            } else if (viewHolder instanceof MsgFromVoiceHolder) {
                setFromVoiceContentView(bean, (MsgFromVoiceHolder) viewHolder);
            }
        }
    }

    private void setToTextContentView(ChatMessage bean, MsgToTextHolder viewHolder) {
        viewHolder.tvSendTime.setText(DateUtils.timestampToString1(bean.getTimeSend() * 1000l));
        viewHolder.chatText.setText(bean.getContent());
        if (bean.getMessageStatus() == 0) {
            viewHolder.imgState.setVisibility(View.VISIBLE);
            viewHolder.imgState.setImageResource(R.drawable.ic_tiktok_send_ing);
        } else if (bean.getMessageStatus() == 1) {
            viewHolder.imgState.setVisibility(View.GONE);
        } else if (bean.getMessageStatus() == 2) {
            viewHolder.imgState.setVisibility(View.VISIBLE);
            viewHolder.imgState.setImageResource(R.drawable.im_send_fail_nor);
        }
    }

    private void setFromTextContentView(ChatMessage bean, MsgFromTextHolder holder) {
        holder.tvSendTime.setText(DateUtils.timestampToString1(bean.getTimeSend() * 1000l));
        holder.chatText.setText(bean.getContent());
//        if (bean.getMessageStatus() == 0) {
//            holder.imgState.setVisibility(View.VISIBLE);
//            holder.imgState.setImageResource(R.drawable.ic_tiktok_send_ing);
//        } else if (bean.getMessageStatus() == 1) {
//            holder.imgState.setVisibility(View.GONE);
//        } else if (bean.getMessageStatus() == 2) {
//            holder.imgState.setVisibility(View.VISIBLE);
//            holder.imgState.setImageResource(R.drawable.im_send_fail_nor);
//        }
    }

    private void setToPicContentView(ChatMessage bean, MsgToPicHolder holder) {

        holder.tvSendTime.setText(DateUtils.timestampToString1(bean.getTimeSend() * 1000l));

        if (!TextUtils.isEmpty(bean.getFilePath())) {
            GlideOptions options = GlideOptions.placeholderOf(R.mipmap.default_error).
                    error(R.mipmap.default_error).skipMemoryCache(false);
            Glide.with(mContext)
                    .asBitmap()
                    .load(bean.getFilePath())
                    .apply(options)
                    .apply(RequestOptions.overrideOf(holder.chatPic.getWidth(), holder.chatPic.getHeight()))
                    .into(new TransformationUtils(holder.chatPic));
        }

        if (bean.getUpLoadStatus() == 1) {   // 上传中
            holder.imgState.setVisibility(View.VISIBLE);
            holder.imgState.setImageResource(R.drawable.ic_tiktok_send_ing);
        } else if (bean.getUpLoadStatus() == 2) { // 上传 成功
            if (bean.getMessageStatus() == 0) {
                holder.imgState.setVisibility(View.VISIBLE);
                holder.imgState.setImageResource(R.drawable.ic_tiktok_send_ing);
            } else if (bean.getMessageStatus() == 1) {
                holder.imgState.setVisibility(View.GONE);
            } else if (bean.getMessageStatus() == 2) {
                holder.imgState.setVisibility(View.VISIBLE);
                holder.imgState.setImageResource(R.drawable.im_send_fail_nor);
            }

        } else if (bean.getUpLoadStatus() == 3) { // 上传失败
            holder.imgState.setVisibility(View.VISIBLE);
            holder.imgState.setImageResource(R.drawable.im_send_fail_nor);
        }
    }

    private void setFromPicContentView(ChatMessage bean, MsgFromPicHolder holder) {

        holder.tvSendTime.setText(DateUtils.timestampToString1(bean.getTimeSend() * 1000l));

        if (!TextUtils.isEmpty(bean.getContent())) {
            GlideOptions options = GlideOptions.placeholderOf(R.mipmap.default_error).
                    error(R.mipmap.default_error).skipMemoryCache(false);
            Glide.with(mContext)
                    .asBitmap()
                    .load(bean.getContent())
                    .apply(options)
                    .apply(RequestOptions.overrideOf(holder.chatPic.getWidth(), holder.chatPic.getHeight()))
                    .into(new TransformationUtils(holder.chatPic));
        }

//        if (bean.getUpLoadStatus() == 1) {   // 上传中
//            holder.imgState.setVisibility(View.VISIBLE);
//            holder.imgState.setImageResource(R.drawable.ic_tiktok_send_ing);
//        } else if (bean.getUpLoadStatus() == 2) { // 上传 成功
//            if (bean.getMessageStatus() == 0) {
//                holder.imgState.setVisibility(View.VISIBLE);
//                holder.imgState.setImageResource(R.drawable.ic_tiktok_send_ing);
//            } else if (bean.getMessageStatus() == 1) {
//                holder.imgState.setVisibility(View.GONE);
//            } else if (bean.getMessageStatus() == 2) {
//                holder.imgState.setVisibility(View.VISIBLE);
//                holder.imgState.setImageResource(R.drawable.im_send_fail_nor);
//            }
//
//        } else if (bean.getUpLoadStatus() == 3) { // 上传失败
//            holder.imgState.setVisibility(View.VISIBLE);
//            holder.imgState.setImageResource(R.drawable.im_send_fail_nor);
//        }
    }

    private void setFromVoiceContentView(ChatMessage bean, MsgFromVoiceHolder holder) {
        holder.tvSendTime.setText(DateUtils.timestampToString1(bean.getTimeSend() * 1000l));

        VoicePlayer.instance().playVoice(holder.chatVoiceAnimView);

        if (!TextUtils.isEmpty(bean.getContent())) {
            holder.chatVoiceAnimView.fillData(bean);
        }
//        if (bean.getUpLoadStatus() == 1) {   // 上传中
//            holder.imgState.setVisibility(View.VISIBLE);
//            holder.imgState.setImageResource(R.drawable.ic_tiktok_send_ing);
//        } else if (bean.getUpLoadStatus() == 2) { // 上传 成功
//            if (bean.getMessageStatus() == 0) {
//                holder.imgState.setVisibility(View.VISIBLE);
//                holder.imgState.setImageResource(R.drawable.ic_tiktok_send_ing);
//            } else if (bean.getMessageStatus() == 1) {
//                holder.imgState.setVisibility(View.GONE);
//            } else if (bean.getMessageStatus() == 2) {
//                holder.imgState.setVisibility(View.VISIBLE);
//                holder.imgState.setImageResource(R.drawable.im_send_fail_nor);
//            }
//
//        } else if (bean.getUpLoadStatus() == 3) { // 上传失败
//            holder.imgState.setVisibility(View.VISIBLE);
//            holder.imgState.setImageResource(R.drawable.im_send_fail_nor);
//        }
    }

    private void setToVoiceContentView(ChatMessage bean, MsgToVoiceHolder holder) {
        holder.tvSendTime.setText(DateUtils.timestampToString1(bean.getTimeSend() * 1000l));
        holder.chatVoiceAnimView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                VoicePlayer.instance().playVoice(holder.chatVoiceAnimView);
            }
        });
        if (!TextUtils.isEmpty(bean.getFilePath())) {
            holder.chatVoiceAnimView.fillData(bean);
        }
        if (bean.getUpLoadStatus() == 1) {   // 上传中
            holder.imgState.setVisibility(View.VISIBLE);
            holder.imgState.setImageResource(R.drawable.ic_tiktok_send_ing);
        } else if (bean.getUpLoadStatus() == 2) { // 上传 成功
            if (bean.getMessageStatus() == 0) {
                holder.imgState.setVisibility(View.VISIBLE);
                holder.imgState.setImageResource(R.drawable.ic_tiktok_send_ing);
            } else if (bean.getMessageStatus() == 1) {
                holder.imgState.setVisibility(View.GONE);
            } else if (bean.getMessageStatus() == 2) {
                holder.imgState.setVisibility(View.VISIBLE);
                holder.imgState.setImageResource(R.drawable.im_send_fail_nor);
            }

        } else if (bean.getUpLoadStatus() == 3) { // 上传失败
            holder.imgState.setVisibility(View.VISIBLE);
            holder.imgState.setImageResource(R.drawable.im_send_fail_nor);
        }
    }

    @Override
    public int getItemViewType(int position) {
        return ChatHolderFactory.getChatHolderType(mLoginUserId, messageList.get(position));
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public int getItemCount() {
        return this.messageList == null ? 0 : this.messageList.size();
    }

    class MsgToTextHolder extends RecyclerView.ViewHolder {
        TextView tvSendTime;
        RoundImageView ivHeader;
        TextView chatText;
        ImageView imgState;

        public MsgToTextHolder(@NonNull View itemView) {
            super(itemView);
            tvSendTime = itemView.findViewById(R.id.tv_send_time);
            ivHeader = itemView.findViewById(R.id.iv_header);
            chatText = itemView.findViewById(R.id.chat_text);
            imgState = itemView.findViewById(R.id.img_state);
        }
    }

    class MsgFromTextHolder extends RecyclerView.ViewHolder {
        TextView tvSendTime;
        RoundImageView ivHeader;
        TextView chatText;
        ImageView imgState;

        public MsgFromTextHolder(@NonNull View itemView) {
            super(itemView);
            tvSendTime = itemView.findViewById(R.id.tv_send_time);
            ivHeader = itemView.findViewById(R.id.iv_header);
            chatText = itemView.findViewById(R.id.chat_text);
            imgState = itemView.findViewById(R.id.img_state);
        }
    }

    class MsgFromPicHolder extends RecyclerView.ViewHolder {

        TextView tvSendTime;
        RoundImageView ivHeader;
        ImageView chatPic;
        ImageView imgState;

        public MsgFromPicHolder(@NonNull View itemView) {
            super(itemView);
            tvSendTime = itemView.findViewById(R.id.tv_send_time);
            ivHeader = itemView.findViewById(R.id.iv_header);
            chatPic = itemView.findViewById(R.id.chat_pic);
            imgState = itemView.findViewById(R.id.img_state);
        }
    }

    class MsgToPicHolder extends RecyclerView.ViewHolder {

        TextView tvSendTime;
        RoundImageView ivHeader;
        ImageView chatPic;
        ImageView imgState;

        public MsgToPicHolder(@NonNull View itemView) {
            super(itemView);
            tvSendTime = itemView.findViewById(R.id.tv_send_time);
            ivHeader = itemView.findViewById(R.id.iv_header);
            chatPic = itemView.findViewById(R.id.chat_pic);
            imgState = itemView.findViewById(R.id.img_state);
        }
    }

    class MsgFromVoiceHolder extends RecyclerView.ViewHolder {

        TextView tvSendTime;
        RoundImageView ivHeader;
        VoiceAnimView chatVoiceAnimView;
        ImageView imgState;

        public MsgFromVoiceHolder(@NonNull View itemView) {
            super(itemView);
            tvSendTime = itemView.findViewById(R.id.tv_send_time);
            ivHeader = itemView.findViewById(R.id.iv_header);
            chatVoiceAnimView = itemView.findViewById(R.id.chat_voice);
            imgState = itemView.findViewById(R.id.img_state);
        }
    }

    class MsgToVoiceHolder extends RecyclerView.ViewHolder {

        TextView tvSendTime;
        RoundImageView ivHeader;
        VoiceAnimView chatVoiceAnimView;
        ImageView imgState;

        public MsgToVoiceHolder(@NonNull View itemView) {
            super(itemView);
            tvSendTime = itemView.findViewById(R.id.tv_send_time);
            ivHeader = itemView.findViewById(R.id.iv_header);
            chatVoiceAnimView = itemView.findViewById(R.id.chat_voice);
            imgState = itemView.findViewById(R.id.img_state);
        }
    }


}
